# CircularQueueDict
Dictionary that acts as a Circular Queue, allowing to set a maximum length and automatically delete oldest element when inputting a new one. Useful for temporal storage of large elements that could overflow memory.
